@@ -34,6 +34,8 @@
 #include <couchdb-document-contact.h>
 #include <couchdb-document-info.h>
 #include <couchdb-document-task.h>
+#include <couchdb-query.h>
+#include <couchdb-response.h>
 #include <couchdb-session.h>
 #include <couchdb-struct-field.h>
 
